
* Webpage: https://gammapy.org
* Documentation: https://docs.gammapy.org
* Code: https://github.com/gammapy/gammapy

Gammapy is an open-source Python package for gamma-ray astronomy built on Numpy and Astropy.
It has been adopted by Cherenkov Telescope Array Observatory as the CTA Science Analysis Tools,
and can also be used to analyse data from existing gamma-ray telescopes.
